@@ -13,12 +13,15 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 #{{{sub new
 sub new {
     my ( $class, @args ) = @_;
     my $authn = $class->SUPER::new(@args);
+    # Set the Referer to /dev/integrationtests in order to be
+    # allowed to post to the Sakai Nakamura instance:
+    $authn->{'Referer'} = "/dev/integrationtests";
     bless $authn, $class;
     return $authn;
 }
